from xml.dom.minidom import Document, Element


def create_element(doc: Document, parent: Element, name: str, text: str) -> None:
    element = doc.createElement(name)
    element.appendChild(doc.createTextNode(text))
    parent.appendChild(element)



#!/usr/bin/python

import logging
import yahoo_oauth


def cleanup():
    # Cleanup the logging in yahoo_oauth.  It creates a logger that writes to
    # stderr.  We are going to recreate the logger so that we can use a handler
    # that writes to our log file.
    logging.setLoggerClass(logging.Logger)
    yahoo_oauth.logger = logging.getLogger('mod_yahoo_oauth')
    logging.getLogger('mod_yahoo_oauth').setLevel(logging.WARN)
